#!/usr/bin/env node

"use strict";
const {
    program
} = require("commander");
const inquirer = require('inquirer');
const fs = require('fs');
const process = require('process');
const {
    green,
    blue,
    red,
    yellow
} = require("../tools/color.js");
const create = require('../src/create');
const start = require('../src/start');
const question = [{
    name: 'conf',
    /* key */
    type: 'confirm',
    /* 确认 */
    message: '是否创建新的项目？' /* 提示 */
}, {
    name: 'name',
    message: '请输入项目名称？',
    when: res => Boolean(res.conf) /* 是否进行 */
}, {
    name: 'author',
    message: '请输入作者？',
    when: res => Boolean(res.conf)
}, {
    type: 'list',
    /* 选择框 */
    message: '请选择技术栈',
    name: 'label',
    choices: ['vue', 'react'],
    /* 选项*/
    filter: function(val) {
        /* 过滤 */
        return val.toLowerCase()
    },
    when: res => Boolean(res.conf)
}, {
    type: 'list',
    /* 选择框 */
    message: '请选择项目类型',
    name: 'type',
    choices: ['pc', 'h5', 'icestarkframework', 'icestarkchild'],
    /* 选项*/
    filter: function(val) {
        /* 过滤 */
        return val.toLowerCase()
    },
    when: res => Boolean(res.conf)
}]

/* mycli create 创建项目 */
program
    .arguments('<createcommand> <dirname>')
    .description('create a project ')
    .action(function(createcommand, dirname) {
        if (fs.existsSync(dirname)) {
            red('该文件夹已存在, 请重新命名');
            return false;
        }
        green('欢迎使用leiyi-cli,快速创建项目🍀🍀');
        inquirer.prompt(question).then(answer => {
            if (answer.conf) {
                fs.mkdirSync(dirname);
                try {
                    process.chdir(`./${dirname}`);
                    // console.log('New directory: ' + process.cwd());
                } catch (err) {
                    red('chdir: ' + err);
                }
                /* 创建文件 */
                create(answer)
            }
        })
    })

/* mycli start 运行项目 */
program
    .command('start')
    .description('start a project')
    .action(function() {
        green('--------运行项目-------')
            /* 运行项目 */
        start('start').then(() => {
            green('-------✅  ✅运行完成-------')
        })
    })

/* mycli build 打包项目 */
program
    .command('build')
    .description('build a project')
    .action(function() {
        green('--------构建项目-------')
            /* 打包项目 */
        start('build').then(() => {
            green('-------✅  ✅构建完成-------')
        })
    })



program.parse(process.argv)