const fs = require("fs");
const color = require("../tools/color");
const path = require('path');
const npm = require("./npm");

module.exports = (res) => {
    function revisePackageJson(res, sourcePath) {
        return new Promise((resolve) => {
            /* 读取文件 */
            fs.readFile(sourcePath + "/package.json", (err, data) => {
                if (err) {
                    color.red(JSON.stringify(res));
                    throw err;
                }
                const {
                    author,
                    name
                } = res;
                let json = data.toString();
                /* 替换模版 */
                json = json.replace(/project/g, name.trim());
                json = json.replace(/proAuthor/g, author.trim());
                const path = process.cwd() + "/package.json";
                /* 写入文件 */
                fs.writeFile(path, json, () => {
                    // color.green("创建文件：" + path);
                    resolve();
                });
            });
        });
    }
    let isInstall = false;

    function completeControl(cb) {
        if (fileCount === 0 && dirCount === 0 && flat === 0) {
            color.green("*****文件生成完成*****");
            if (cb && !isInstall) {
                isInstall = true;
                color.blue("*****开始install*****");
                /* 下载项目 */
                cb(() => {
                    color.blue("*****完成install*****");
                    runProject();
                });
            }
        }
    }

    function runProject() {
        try {
            /* 继续调用 npm 执行，npm start 命令 */
            const start = npm(["start"]);
            start();
        } catch (e) {
            color.red("自动启动失败，请手动npm start 启动项目");
        }
    }

    let fileCount = 0; /* 文件数量 */
    let dirCount = 0; /* 文件夹数量 */
    let flat = 0; /* readir数量 */
    /**
     *
     * @param {*} sourcePath   //template资源路径
     * @param {*} currentPath  //当前项目路径
     * @param {*} cb           //项目复制完成回调函数
     */
    function copy(sourcePath, currentPath, cb) {
        flat++;
        /* 读取文件夹下面的文件 */
        fs.readdir(sourcePath, (err, paths) => {
            flat--;
            if (err) {
                throw err;
            }
            paths.forEach((path) => {
                if (![".git", "package.json", ".DS_Store"].includes(path)) {
                    fileCount++;
                    const newSoucePath = sourcePath + "/" + path;
                    const newCurrentPath = currentPath + "/" + path;
                    /* 判断文件信息 */
                    fs.stat(newSoucePath, (err, stat) => {
                        if (err) {
                            throw err;
                        }
                        /* 判断是文件，且不是 package.json  */
                        if (stat.isFile()) {
                            /* 创建读写流 */
                            const readSteam = fs.createReadStream(newSoucePath);
                            const writeSteam = fs.createWriteStream(newCurrentPath);
                            readSteam.pipe(writeSteam);
                            // color.green("创建文件：" + newCurrentPath);
                            fileCount--;
                            completeControl(cb);
                            /* 判断是文件夹，对文件夹单独进行 dirExist 操作 */
                        } else if (stat.isDirectory()) {
                            // if (path !== ".git" && path !== "package.json" && path !== ".DS_Store") {
                                dirCount++;
                                dirExist(newSoucePath, newCurrentPath, copy, cb);
                            // }
                        }
                    });
                }
            });
        });
    }

    /**
     *
     * @param {*} sourcePath  //template资源路径
     * @param {*} currentPath  //当前项目路径
     * @param {*} copyCallback  // 上面的 copy 函数
     * @param {*} cb    //项目复制完成回调函数
     */
    function dirExist(sourcePath, currentPath, copyCallback, cb) {
        fs.exists(currentPath, (ext) => {
            if (ext) {
                /* 递归调用copy函数 */
                copyCallback(sourcePath, currentPath, cb);
            } else {
                fs.mkdir(currentPath, () => {
                    fileCount--;
                    dirCount--;
                    copyCallback(sourcePath, currentPath, cb);
                    // color.yellow("创建文件夹：" + currentPath);
                    completeControl(cb);
                });
            }
        });
    }

    /* 创建文件 */
    color.green("*****生成项目文件*****");
    /* 找到template文件夹下的模版项目 */
    const {
        label,
        type
    } = res;
    const sourcePath = path.join(__dirname.slice(0, -3), "template", label, type);
    // color.blue("当前路径:" + process.cwd());
    // color.green(sourcePath);
    /* 修改package.json*/
    revisePackageJson(res, sourcePath).then(() => {
        copy(sourcePath, process.cwd(), npm());
    });
};