//是否生产环境。process为webpack编译时的全局变量。
const isPrd = process.env.NODE_ENV === 'production';

/**
 * 定义Eslint的校验规则
 * 官方文档：http://eslint.cn/docs/rules/
 */
module.exports = {
  //是否从父级目录查找配置文件。为true，则不从父级目录查找。
  root: true,
  //指定你想启用的环境
  env: {
    browser: true, //浏览器环境：使用浏览器运行代码
    node: true, //node环境：使用node.js运行代码
    es6: true, //ES6环境：允许使用Promise、Uint8Array等全局对象
  },
  //指定解析器。需要安装babel-eslint：一个对Babel解析器的包装，使其能够与ESLint兼容。
  parser: 'babel-eslint',
  //解析器配置
  parserOptions: {
    ecmaVersion: 2018, //支持ES2018语法
    sourceType: 'module', //指定代码是ECMAScript模块。如果不指定，那么直接在js中import、export会报错。
    //额外支持的语法
    ecmaFeatures: {
      jsx: true, //支持JS语法糖
      legacyDecorators: true, //用来支持修饰器(@)写在class上面
    },
  },
  //使用Eslint默认的校验规则
  extends: ['eslint:recommended'],
  //使用eslint-plugin-react插件
  plugins: ['react'],
  /**
   * 自定义的校验规则
   * 0或off：关闭规则
   * 1或warn：警告提示
   * 2或error：错误提示
   */
  rules: {
    /*****************Eslint的基本检查*****************/

    //no-console代表禁止打印日志。
    'no-console': isPrd ? 2 : 0,
    //禁止调试
    'no-debugger': isPrd ? 2 : 0,
    //禁止未使用的变量、函数
    'no-unused-vars': 0,
    //禁止使用不必要的转义符
    'no-useless-escape': 0,

    /*****************react的检查*****************/

    //react的属性检查：建议关闭
    'react/prop-types': 0,
    //react的状态检查：建议关闭
    'react/no-direct-mutation-state': 0,
    //react中数组的key：建议关闭，因为很容易误判
    'react/jsx-key': 0,
    //react的组件名需要名字。非组件的render函数会误判
    'react/display-name': 0,
  },
};
