//国际化配置
import dataLocale from '../locales';

/**
 * 国际化工具类
 */
export default {
  /**
   * 获取国际化资源
   * @param id 资源id，格式为string
   * @param values 变量，格式为Object
   */
  getMessage(id, values) {
    let msg = dataLocale.messages[id]; //原始的国际化资源
    if (!msg) return '';

    let list = msg.match(/\{[^{}\n]*(?=\})/g); //取出所有的变量。为兼容IE，不使用先行断言。
    if (list && list.length > 0) {
      list.forEach((item) => {
        item = item.replace(/\{/, ''); //去掉"{"
        let re = new RegExp(`\{${item}\}`, 'g');

        msg = msg.replace(re, values[item]); //替换变量后的国际化资源
      });
    }
    return msg;
  },
  /**
   * 获取网路错误提示
   * @param code 状态码
   * @param msg 网络错误
   */
  getNetwork(code, msg) {
    let result = msg;

    if (code) {
      result = this.getMessage(`network.${code}`);
    } else if (msg.startsWith('timeout')) {
      let count = msg.match(/\s\d*(?=ms)/)[0]; //超时时间。为兼容IE，不使用先行断言。
      count = count.replace(/\s/, '');
      result = this.getMessage('network.timeout', {count});
    } else {
      result = this.getMessage('network.common'); //如果该错误没有国际化，则使用通用提示
    }

    return result;
  },
};
