import Vue from "vue";
import Vuex from "vuex";
// 引入针对vuex数据持久化处理的插件
import createPersistedState from "vuex-persistedstate";
Vue.use(Vuex);

const context = require.context("./modules", false, /.js/);
const moduleStores = {};

context.keys().forEach((key) => {
  // 获取读取到的文件名字并且截取
  const fileName = key.slice(2, -3);
  //通过 context(key)导出文件内容
  const fileModule = context(key).default;
  moduleStores[fileName] = {
    ...fileModule,
  };
});
export default new Vuex.Store({
  namespaced: true,
  // 数据持久化，createPersistedState()为空表示默认存储localStorage
  plugins: [
    createPersistedState({
      storage: window.sessionStorage,
      // 方法1：用reducer，这里的val是由store里面的所有state，不加reducer为储存所有，reducer为指定存储
      // reducer(val) {
      //     return {
      //         // 只储存Home中的name属性，存储的键名为name
      //         name: val.Home.name
      //     }
      // }
      // 方法2：用paths,数组里面填模块名，存储指定模块
      paths: ["Home", "Order"],
    }),
  ],
  modules: {
    ...moduleStores,
  },
});
