import Vue from "vue";
import VueRouter from "vue-router";
// 引入需要配置动态路由的路由地址
import dynamicroute from "./dynamicroute";
// 根据文件层级路径设置路由，无需手动配置路由
// 读取views下的所有vue文件
const routeFiles = require.context("../views", true, /.vue$/);
Vue.use(VueRouter);
// 按照文件层级设置文件添加pId标识
const routeObj = routeFiles.keys().reduce((obj, cur) => {
  // 需要过滤的路由
  if (!["./404/index.vue"].includes(cur)) {
    let strArr = cur.split("/");
    let path = sliceStr(strArr, 1);
    let pId = sliceStr(strArr, 2);
    obj[path] = {
      path: dynamicroute.includes(path) ? `${path}/:id` : path,
      pId,
      component: routeFiles(cur).default,
    };
  }
  return obj;
}, {});
//截取字符串并替换index
function sliceStr(str, len) {
  return str
    .slice(0, str.length - len)
    .join("/")
    .slice(1)
    .replace(/index\/?/, "");
}
// 按照文件层级格式化路由
function formatList(obj) {
  const routeList = [];
  let item;
  for (item in obj) {
    let val = obj[item];
    let parent = routeObj[val.pId];
    if (parent) {
      (parent.children || (parent.children = [])).push(val);
    } else {
      routeList.push(val);
    }
  }
  return routeList;
}
const routes = formatList(routeObj);
const router = new VueRouter({
  mode: "history",
  base: process.env.BASE_URL,
  routes: [
    ...routes,
    {
      path: "*",
      component: () => import("@/views/404"),
    },
  ],
});
// router.push重写
const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
}
//router.place重写
const originalReplace = VueRouter.prototype.replace
originalReplace.replace = function replace(location) {
  return originalReplace.call(this, location).catch(err => err)
}


export default router;